/*
 * Copyright (c) 2019 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <cutils/fs.h>
#define LOG_TAG "init_gles_version"
#include <cutils/log.h>
#include <cutils/properties.h>


void init_gles_version()
{
    static const char s_OpenGLESv21[] = "131072";
    static const char s_OpenGLESv30[] = "196608";
    static const char s_settings_file[] = "/data/misc/fairphone/experimental_gles3";

    int experimental_gles3;
    if (fs_read_atomic_int(s_settings_file, &experimental_gles3) != 0) {
        SLOGI("experimental_gles3 property not set. Defaulting to 0.");
        experimental_gles3 = 0;
    } else {
        SLOGI("Reading experimental_gles3 value of %i", experimental_gles3);
    }

    property_set(
        "ro.opengles.version",
        experimental_gles3 ? s_OpenGLESv30 : s_OpenGLESv21);
}
